package com.ruoyi.basicData.service;

import com.ruoyi.basicData.domain.TCorps;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.domain.model.LoginUser;

import java.util.List;
import java.util.Map;


/**
 * 客户详情Service接口
 *
 * @author ruoyi
 * @date 2020-12-11
 */
public interface ITCorpsService {
    /**
     * 查询客户详情
     *
     * @param fId 客户详情ID
     * @return 客户详情
     */
    public Map<String, Object> selectTCorpsById(Long fId);

    /**
     * 查询客户详情列表
     *
     * @param tCorps 客户详情
     * @return 客户详情集合
     */
    public List<TCorps> selectTCorpsList(TCorps tCorps);

    /**
     * 新增客户详情
     *
     * @param tCorps 客户详情
     * @param loginUser
     * @return 结果
     */
    public AjaxResult insertTCorps(String tCorps, String tCustomerContacts, LoginUser loginUser);

    /**
     * 修改客户详情
     *
     * @param tCorps 客户详情
     * @return 结果
     */
    public AjaxResult updateTCorps(TCorps tCorps);

    /**
     * 批量删除客户详情
     *
     * @param fIds 需要删除的客户详情ID
     * @return 结果
     */
    public AjaxResult deleteTCorpsByIds(Long[] fIds);

    /**
     * 删除客户详情信息
     *
     * @param fId 客户详情ID
     * @return 结果
     */
    public int deleteTCorpsById(Long fId);

    /**
     *  检验编号唯一
     * @return
     */
    public String checkUFNoUnique(TCorps tCorps);

    /**
     *  检验编号名称
     * @return
     */
    public String checkUFNnameUnique(TCorps tCorps);

    /**
     *  检验编号地址
     * @return
     */
    public String checkUFCnameUnique(TCorps tCorps);
}
